==> mastercard_mc_on-1.0.2.tar.gz: mastercard_mc_on-1.0.2/mastercardmcon/wifi.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from __future__ import absolute_import
from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from mastercardmcon import ResourceConfig

class Wifi(BaseObject):
    """
    
    """

    __config = {
        
        "d4555c2d-2d0f-4e0a-a9a0-2882d093c0ef" : OperationConfig("/loyalty/v1/users/{userId}/wifi", "query", ["x-client-correlation-id"], []),
        
        "1ee39508-b170-4cc8-92ed-f46df7024180" : OperationConfig("/loyalty/v1/wifi", "query", ["x-client-correlation-id"], ["latitude","longitude","radius"]),
        
    }

    def getOperationConfig(self,operationUUID):
        if operationUUID not in self.__config:
            raise Exception("Invalid operationUUID: "+operationUUID)

        return self.__config[operationUUID]

    def getOperationMetadata(self):
        return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative(), ResourceConfig.getInstance().getContentTypeOverride())







    @classmethod
    def userWifiRegistrationStatus(cls,criteria):
        """
        Query objects of type Wifi by id and optional criteria
        @param type criteria
        @return Wifi object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("d4555c2d-2d0f-4e0a-a9a0-2882d093c0ef", Wifi(criteria))






    @classmethod
    def getWifi(cls,criteria):
        """
        Query objects of type Wifi by id and optional criteria
        @param type criteria
        @return Wifi object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("1ee39508-b170-4cc8-92ed-f46df7024180", Wifi(criteria))

==> mastercard_mc_on-1.0.3.tar.gz: mastercard_mc_on-1.0.3/mastercardmcon/wifi.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from __future__ import absolute_import
from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from mastercardmcon import ResourceConfig

class Wifi(BaseObject):
    """
    
    """

    __config = {
        
        "3f47915b-73eb-4a83-8899-c0fbc27da486" : OperationConfig("/loyalty/v1/users/{userId}/wifi", "query", ["x-client-correlation-id"], []),
        
        "0c6cb9ee-c019-4db9-b613-03daf57e572f" : OperationConfig("/loyalty/v1/wifi", "query", ["x-client-correlation-id"], ["latitude","longitude","radius"]),
        
    }

    def getOperationConfig(self,operationUUID):
        if operationUUID not in self.__config:
            raise Exception("Invalid operationUUID: "+operationUUID)

        return self.__config[operationUUID]

    def getOperationMetadata(self):
        return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative(), ResourceConfig.getInstance().getContentTypeOverride())







    @classmethod
    def userWifiRegistrationStatus(cls,criteria):
        """
        Query objects of type Wifi by id and optional criteria
        @param type criteria
        @return Wifi object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("3f47915b-73eb-4a83-8899-c0fbc27da486", Wifi(criteria))






    @classmethod
    def getWifi(cls,criteria):
        """
        Query objects of type Wifi by id and optional criteria
        @param type criteria
        @return Wifi object representing the response.
        @raise ApiException: raised an exception from the response status
        """

        return BaseObject.execute("0c6cb9ee-c019-4db9-b613-03daf57e572f", Wifi(criteria))
